import React, { useEffect } from 'react'
import { makeStyles } from '@material-ui/core/styles'
import ExpansionPanel from '@material-ui/core/ExpansionPanel'
import ExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary'
import ExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails'
import Typography from '@material-ui/core/Typography'
import ExpandMoreIcon from '@material-ui/icons/ExpandMore'

import $ from 'jquery'
import config from '../local/js/config'

const useStyles = makeStyles(theme => ({
  root: {
    width: '100%',
    marginTop: '1vh'
  },
  heading: {
    fontSize: theme.typography.pxToRem(15),
    fontWeight: theme.typography.fontWeightRegular
  },
  expanded: {
    margin: '0 !important'
  },
  mainDiv: {
    borderBottom: '0.5vh solid ' + config.SecondaryColor,
    borderBottomLeftRadius: '1vh',
    borderBottomRightRadius: '1vh'
  },
  accordionHeadF: {
    backgroundColor: config.PrimaryColor,
    color: 'white',
    border: '0.5vh solid ' + config.SecondaryColor,
    borderBottom: 0,
    borderTopLeftRadius: '1vh',
    borderTopRightRadius: '1vh',
    minHeight: '0 !important'
  },
  accordionHead: {
    backgroundColor: config.PrimaryColor,
    color: 'white',
    border: '0.5vh solid ' + config.SecondaryColor,
    borderBottom: 0,
    minHeight: '0 !important'
  },
  accordionBody: {
    borderLeft: '0.5vh solid ' + config.EbookColor,
    borderRight: '0.5vh solid ' + config.EbookColor,
    padding: '2vh',
    overflowY: 'auto',
    maxHeight: '20vh'
  },
  icon: {
    color: 'white',
    padding: '1vh'
  },
  sumaryContent: {
    margin: '0 !important',
    '& p': {
      marginBottom: '0px !important'
    }
  },
  headExpand: {
    backgroundColor: config.EbookColor,
    borderColor: config.EbookColor
  }
}))

export default function SimpleExpansionPanel (props) {
  const classes = useStyles()
  const [expanded, setExpanded] = React.useState(false)

  const handleChange = panel => (event, isExpanded) => {
    setExpanded(isExpanded ? panel : false)
  }

  useEffect(() => {
    setExpanded('panel0')
  }, [])

  return (
    <div className={classes.root}>
      {props.Content.map((value, index) => {
        return <ExpansionPanel expanded={expanded === 'panel' + index} onChange={handleChange('panel' + index)} classes={{ expanded: classes.expanded, root: index == (props.Content.length - 1) ? classes.mainDiv : '' }} defaultExpanded={index == 0} >
          <ExpansionPanelSummary
            expandIcon={<ExpandMoreIcon />}
            aria-controls='panel1a-content'
            id='panel1a-header'
            classes={{ root: index == 0 ? classes.accordionHeadF : classes.accordionHead, expandIcon: classes.icon, content: classes.sumaryContent, expanded: classes.headExpand }}
          >
            <Typography className={classes.heading}>{value.header}</Typography>
          </ExpansionPanelSummary>
          <ExpansionPanelDetails classes={{ root: classes.accordionBody }}>
            <Typography>
              {value.content}
            </Typography>
          </ExpansionPanelDetails>
        </ExpansionPanel>
      })}

    </div>
  )
}
