import React, { useEffect } from 'react'
import { makeStyles } from '@material-ui/core/styles'
import SwipeableDrawer from '@material-ui/core/SwipeableDrawer'

import List from '@material-ui/core/List'
import ListItem from '@material-ui/core/ListItem'
import ListItemIcon from '@material-ui/core/ListItemIcon'
import ListItemText from '@material-ui/core/ListItemText'

import Sumary from '@material-ui/icons/FormatListBulleted'
import Reference from '@material-ui/icons/FormatQuote'
import FontSize from '@material-ui/icons/FormatSize'
import Credits from '@material-ui/icons/Stars'
import Pages from '@material-ui/icons/FileCopy'
import Notes from '@material-ui/icons/Create'
import PrevIcon from '@material-ui/icons/NavigateBefore'
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft'
import Divider from '@material-ui/core/Divider'

import IconButton from '@material-ui/core/IconButton'
import MenuIcon from '@material-ui/icons/Menu'
import styled from 'styled-components'
import config from '../local/js/config'
import $ from 'jquery'

import Sumario from './Menu/Sumario'
import Referencias from './Menu/Referencias'
import TamanhoFonte from './Menu/TamanhoFonte'
import Creditos from './Menu/Creditos'
import Paginas from './Menu/Paginas'
import BaixarAnotacoes from './Menu/BaixarAnotacoes'
import ltiKey from '../core/js/LTI'

const ltik = ltiKey()

const MainDiv = styled.div`
  margin-left: 0%;
  @media (min-width: ${config.MobileBreakpoint + 'px'}) {
    margin-left: 1%;
  }
  .MuiIconButton-root{
    cursor: pointer;
    background-color: ${config.EbookColor};
    padding: calc(1vh);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      background-color: ${config.ButtonColor};
      padding: calc(0.2vh + 0.2vw);
    } 
  }
  .MuiIconButton-root:hover {
    background-color: ${config.ButtonColor};
  }
  .MuiSvgIcon-root{
    color: white;
    font-size: calc(2vh + 2vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      font-size: calc(2vh + 1vw);
    }
  }
  .menuButton{
    margin-left: 0%;
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      margin-left: 5%;
    }
  }
  .prevButton, .nextButton{
    background-color: ${config.ButtonColor} !important;
    padding: calc(0.8vh + 0vw) !important
  }
  .MuiLinearProgress-bar{
    background-color: ${config.EbookColor}
  }
  .MuiList-root{
    display: flex;
    flex-flow: column;
    flex-direction: column;
    height: 100vh;
    
  }
  
  .itemText{
    font-size: ${props => props.sizeText + 'px'};
  }
  
`

const useStyles = makeStyles({
  list: {
    width: '37vh'
  },
  itemText: {
    fontSize: props => props.sizeText + 'px'
  },
  fullList: {
    width: 'auto'
  },
  menuitems: {
    color: props => props.color,
    fontSize: window.innerWidth >= config.MobileBreakpoint ? 'calc(1vh + 1vw)' : 'calc(2vh + 2vw)'
  },
  backBtn: {
    float: 'right',
    minWidth: '0',
    display: 'none'
  },
  drawerHeader: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-end',
    cursor: 'pointer'
  },
  noPad: {
    paddingTop: '0px',
    display: 'flex',
    flexFlow: 'column',
    flexDirection: 'column',
    height: $(window).height()
  },
  iconstyle: {
    minWidth: 0,
    marginRight: '2vh'
  },
  paper: {
    overflowY: 'hidden',
    overflowX: 'hidden'
  }
})

export default function SwipeableTemporaryDrawer (props) {
  const classes = useStyles(props)
  const [state, setState] = React.useState({
    left: false,
    estado: 'menu',
    page: props.page,
    maxPage: props.maxPage,
    code: props.Code
  })

  const menuState = menu => {
    $('.menu_' + menu).show()
    $(document).trigger('open_' + menu)
  }

  const openSubMenu = (menu) => {
    if (state.estado === 'menu') {
      $('.' + menu).removeClass('menuItem')
      $('.closeBtn').fadeOut(0, 'linear')
      $('.menuItem').fadeOut(0, 'linear', () => $('.backBtn').fadeIn(0, 'linear', () => menuState(menu)))
      setState({ ...state, estado: menu })
      $(document).trigger('log', [{ type: 'open_' + menu }])
    } else {
      $('.menu_' + menu).hide(0, 'linear', () => $('.backBtn').fadeOut(0, 'linear', () => $('.menuItem').fadeIn(0, 'linear', () => $('.closeBtn').fadeIn(0, 'linear'))))
      $('.' + menu).addClass('menuItem')
      setState({ ...state, estado: 'menu' })
    }
  }

  const toggleDrawer = (side, open) => event => {
    if (event && event.type === 'keydown' && (event.key === 'Tab' || event.key === 'Shift')) {
      return
    }

    setState({ ...state, estado: 'menu', [side]: open })

    if (open == true) $(document).trigger('log', [{ type: 'open_drawer' }])
  }

  const fontratio = () => { return $(window).width() >= config.MobileBreakpoint ? 1 : 1 }
  $(window).resize(() => {
    $('.itemText').css('font-size', ((fontratio() / 100) * ((95 / 100) * $(window).height())) + ((fontratio() / 100) * $(window).height()))
    $('.menuItems').css('font-size', $(window).width() >= config.MobileBreakpoint ? 'calc(1vh + 1vw)' : 'calc(2vh + 2vw)')
  })

  useEffect(() => {
    $(document).on('updateMenu', (e, maxpage, page, menu, subMenu, code) => {
      if (menu && code == state.code) setState({ ...state, maxPage: maxpage, page: page, left: true, estado: subMenu })
      else setState({ ...state, maxPage: maxpage, page: page, left: false })
    })
    $(window).resize(() => { $('.MuiList-root').css('height', $(window).height()) })
    $(document).on('openRef', (e, ref, modal) => {
      $('.menuButton').first().trigger('click')
      openSubMenu('referencias')

      if (modal) {
        setTimeout(() => {
          $('.menu_referencias').scrollTop($('#ref' + ref).offset().top - $('.menu_referencias').offset().top + $('.menu_referencias').scrollTop())
        }, 200)
      } else $('.menu_referencias').scrollTop($('#ref' + ref).offset().top - $('.menu_referencias').offset().top + $('.menu_referencias').scrollTop())
      $('#ref' + ref).addClass('focused')
      $('#ref' + ref).hover(function () {
        $(this).removeClass('focused')
      })
    })
  }, [])

  return (
    <MainDiv className='noselect' sizeText={((fontratio() / 100) * ((95 / 100) * $(window).height())) + ((fontratio() / 100) * $(window).height())}>
      <IconButton edge='start' className='menuButton' color='inherit' aria-label='menu' onClick={toggleDrawer('left', true)}>
        <MenuIcon />
      </IconButton>

      <SwipeableDrawer
        open={state.left}
        onClose={toggleDrawer('left', false)}
        onOpen={toggleDrawer('left', true)}
        classes={{ paper: classes.paper }}
      >
        <div
          className={classes.list}
          role='presentation'

        >
          <List className={classes.noPad} >
            <div className={classes.drawerHeader + ' closeBtn'} onClick={toggleDrawer('left', false)} style={{ 'min-height': '6vh' }}>
              <IconButton onClick={toggleDrawer('left', false)}>
                <ChevronLeftIcon />
              </IconButton>
            </div>
            <Divider className='closeBtn' />
            <ListItem button key='SUMÁRIO' className='menuItem sumario' onClick={() => openSubMenu('sumario')} style={{ 'min-height': '6vh' }} >
              <ListItemIcon className={classes.iconstyle}>
                <Sumary className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='SUMÁRIO' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>
            <Sumario page={state.maxPage} Code={state.code} />
            <ListItem button key='REFERÊNCIAS' className='menuItem referencias' onClick={() => openSubMenu('referencias')} style={{ 'min-height': '6vh' }}>
              <ListItemIcon className={classes.iconstyle}>
                <Reference className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='REFERÊNCIAS' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>
            <Referencias page={state.page} />
            <ListItem button key='TAMANHO DA FONTE' className='menuItem fonte' onClick={() => openSubMenu('fonte')} style={{ 'min-height': '6vh' }}>
              <ListItemIcon className={classes.iconstyle}>
                <FontSize className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='TAMANHO DA FONTE' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>
            <TamanhoFonte page={state.page} />
            <ListItem button key='CRÉDITOS' className='menuItem creditos' onClick={() => openSubMenu('creditos')} style={{ 'min-height': '6vh' }}>
              <ListItemIcon className={classes.iconstyle}>
                <Credits className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='CRÉDITOS' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>
            <Creditos page={state.page} />
            <ListItem button key='PÁGINAS' className='menuItem paginas' onClick={() => openSubMenu('paginas')} style={{ 'min-height': '6vh' }} >
              <ListItemIcon className={classes.iconstyle}>
                <Pages className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='PÁGINAS' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>
            <Paginas page={state.page} maxPage={state.maxPage} Code={state.code} />
            
            {ltik ? ([<ListItem button key='ANOTAÇÕES' className='menuItem notes' onClick={() => openSubMenu('notes')} style={{ 'min-height': '6vh' }}>
              <ListItemIcon className={classes.iconstyle}>
                <Notes className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
              <ListItemText classes={{ primary: 'itemText ' + classes.itemText }} primary='ANOTAÇÕES' />
              <ListItemIcon className={classes.backBtn + ' backBtn'}>
                <PrevIcon className={classes.menuitems + ' menuItems'} />
              </ListItemIcon>
            </ListItem>, 
            <BaixarAnotacoes />]) : ('') }
          </List>
        </div>
      </SwipeableDrawer>
    </MainDiv>
  )
}
