import React from 'react'
import styled from 'styled-components'
import Storage from '../core/js/Storage'

// Imports

// Assets
import muitoInsatisfeito from '../local/media/images/muitoInsatisfeito.svg'
import insatisfeito from '../local/media/images/insatisfeito.svg'
import muitoSatisfeito from '../local/media/images/muitoSatisfeito.svg'
import neutro from '../local/media/images/neutro.svg'
import satisfeito from '../local/media/images/satisfeito.svg'

import config from '../local/js/config'
import $ from 'jquery'
import ltiKey from '../core/js/LTI'

// Styling
const CaixaDiv = styled.div`
    width: 90%;
    background-color: #efefef;
    border-radius: 1vh;
    padding: 3vh 1vh;
    margin-bottom: 1vh;
    position: relative;
    .fb_question{
        text-align: left;
    }
    .fb_box{
        width: 20%;
        text-align: center;
        p{
            margin-top: 1.4vh;
            text-align: center;
        }
        margin-right: 1vh;
        margin-left: 1vh;
    }
    .w-10{
        width: 80%;
        transition: transform 0.2s ease;
        &:hover{
            transform: scale(1.2)
        }
        cursor: pointer;
    }
    .feedback-message{
        word-spacing: normal;
        text-align: left !important;
        margin-left: 3vh;
    }
    .feedback-box{
        margin-top: 2vh;
    }
    &.feedback-sent{
        opacity: 0.5;
        cursor: default;
        .w-10{
            cursor: default;
            &:hover{
                transform: scale(1)
            }
        }
    }
`
const ltik = ltiKey()
// Component
class FeedBack extends React.Component {
  // Constructor
  constructor (props) {
    super(props)
    this.state = {
      // Acess this.props
      id: this.props.Id,
      content: this.props.Content,
      sent: false
    }
  }

  // Scripts

  // Called when rendered
  componentDidMount () {
    $('.icone-head').css('top', -$('.icone-head').outerHeight() / 2)
    $(window).resize(() => {
      const f_t = ((1 / 100) * ($('.Ebook').width() * 0.95)) + ((1 / 100) * $('.Ebook').height())
      $('.texto').css('font-size', f_t)
      $('.icone-head').css('top', -$('.icone-head').outerHeight() / 2)
    })

    $(document).ready(async () => {
      if (ltik) {
        const fb = await Storage.retrieveLocal('feedback_' + this.state.id)
        if (fb) {
          console.log(fb)
          $('#fb_' + this.state.id).addClass('feedback-sent')
          this.setState({ sent: true })
          $('#feedback_' + this.state.id + '_' + (fb.score + 1)).css('transform', 'scale(1.2)')
        } else {
          Storage.retrieveFeedback(this.state.id).then((response) => {
            if (response) {
              $('#fb_' + this.state.id).addClass('feedback-sent')
              this.setState({ sent: true })
              $('#feedback_' + this.state.id + '_' + (response.score + 1)).css('transform', 'scale(1.2)')
            }
          })
        }
      }
    })
  }

  async sendFeedback (score, additional) {
    console.log(score)
    const feedback = {
      score: score,
      additional: additional
    }
    if (!this.state.sent && (!ltik || await Storage.saveFeedback(this.state.id, feedback))) {
      $('#fb_' + this.state.id).addClass('feedback-sent')
      this.setState({ sent: true })
      $('#feedback_' + this.state.id + '_' + (score + 1)).css('transform', 'scale(1.2)')
    }
  }

  render () {
    return (
    // Content
      <div className='grid-row caixa d-flex justify-content-center noselect' >
        <CaixaDiv sizeText={((1 / 100) * ((95 / 100) * $(window).height())) + ((1 / 100) * $(window).height())} id={'fb_' + this.state.id} className='shadow feedback'>
          <p className='text-center mb-3 feedback-message'>
            <strong>{this.state.content}</strong>
          </p>
          <div className='d-flex feedback-box justify-content-around w-100'>

            <div class='fb_box noselect'><img className='w-10' id={'feedback_' + this.state.id + '_1'} onClick={() => this.sendFeedback(0)} src={muitoInsatisfeito} alt='muito insatisfeito' /><p>Discordo totalmente</p></div>
            <div class='fb_box noselect'><img className='w-10' id={'feedback_' + this.state.id + '_2'} onClick={() => this.sendFeedback(1)} src={insatisfeito} alt='instatisfeito' /><p>Discordo</p></div>
            <div class='fb_box noselect'><img className='w-10' id={'feedback_' + this.state.id + '_3'} onClick={() => this.sendFeedback(2)} src={neutro} alt='neutro' /><p>Não concordo nem discordo</p></div>
            <div class='fb_box noselect'><img className='w-10' id={'feedback_' + this.state.id + '_4'} onClick={() => this.sendFeedback(3)} src={satisfeito} alt='satisfeito' /><p>De acordo</p></div>
            <div class='fb_box noselect'><img className='w-10' id={'feedback_' + this.state.id + '_5'} onClick={() => this.sendFeedback(4)} src={muitoSatisfeito} alt='muito satisfeito' /><p>Totalmente de acordo</p></div>
          </div>
        </CaixaDiv>
      </div>
    )
  }
}
export default FeedBack
