import React from 'react'

import IconButton from '@material-ui/core/IconButton'
import MarkerIcon from '@material-ui/icons/Create'
import CommentsIcon from '@material-ui/icons/Textsms'

import styled from 'styled-components'
import config from '../local/js/config'

import $ from 'jquery'

import MarkerFunctionalities from '../core/js/MarkerFunctionalities.js'
import CommentsFunctionalities from '../core/js/CommentsFunctionalities.js'

import Storage from '../core/js/Storage'
import PDFConverter from '../core/js/PDFConverter'
import hashPages from '../core/js/hashPages'

import ltiKey from '../core/js/LTI'

const StyledDiv = styled.div`
  display: flex;
  margin-left: 0.3vh;
  

  .menuButton{
    margin-left: 1vh;
  }
  .MuiIconButton-root{
    cursor: pointer;
    background-color: ${config.EbookColor};
    padding: 1.2vh;
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      background-color: ${config.ButtonColor};
      padding: 0.9vh;
    } 
  }
  .MuiIconButton-root:hover {
    background-color: ${config.ButtonColor};
  }
  .MuiSvgIcon-root{
    color: white;
    font-size: calc(1.6vh + 2vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      font-size: calc(1.6vh + 1vw);
    }
  }
 
  
`

let firstLoad = true
// Page
class Marker extends React.Component {
  constructor (props) {
    super(props)
    if (ltiKey()) {
      let Hgts = []
      let Cmts = []

      Storage.retrieveComments().then(response => {
        if (response) {
          Cmts = response
          this.setState({ Comments: Cmts })
        }
      })

      Storage.retrieveHighlights().then(response => {
        firstLoad = false
        if (response) {
          Hgts = response
          this.setState({ Highlights: Hgts })
          this.changePage()
        }
      })

      this.state = {
        Highlights: Hgts,
        Comments: Cmts,
        curPage: this.props.page
      }

      $(document).on('updatePage', (e, page) => {
        this.setState({ curPage: page })
        $(document).ready(() => {
          this.changePage()
        })
      })

      $(document).on('downloadComments', (e) => {
        console.log('Baixar')
        e.stopImmediatePropagation()
        PDFConverter.createPDF(this.state.Comments)
        $(document).trigger('log', [{ type: 'download_comments' }])
      })
    }
  }

  componentDidMount () {
    $('.marker_btn').on('touchstart mousedown', e => {
      e.stopImmediatePropagation()
      $('.marker_btn').addClass('active_btn')
      this.markText()
      $(document).trigger('log', [{ type: 'make_highlight' }])
    })

    $('.comments_btn').on('touchstart mousedown', e => {
      e.stopImmediatePropagation()
      $('.marker_btn').removeClass('active_btn')
      $('.comments_btn').addClass('active_btn')
      this.makeNote()
      $(document).trigger('log', [{ type: 'make_comment' }])
    })
  }

  async markText () {
    const mark = await MarkerFunctionalities.marcaTexto(this.state, 1, this.state.curPage)
    if (mark) this.saveHgt(mark)
  }

  async makeNote () {
    const note = await MarkerFunctionalities.marcaTexto(this.state, 2, this.state.curPage)
    if (note) {
      this.saveHgt(note)
      const id = note.hashid
      const pos = note.highlight.position

      const comment = await CommentsFunctionalities.criarComentario(id, pos, this.state, hashPages(this.state.curPage))
      if (comment) this.saveCmt(comment)
      else {
        MarkerFunctionalities.excluiMarcacao(id)
        this.deletarHgt(id)
      }
    }
  }

  saveHgt (hgt) {
    this.registraListeners()
    hgt.page = hashPages(this.state.curPage)
    Storage.saveHighlights(hgt)
    const Hgts = this.state.Highlights
    Hgts.push(hgt)
    this.setState({
      Highlights: Hgts
    })
    if (window.getSelection) {
      if (window.getSelection().empty) { // Chrome
        window.getSelection().empty()
      } else if (window.getSelection().removeAllRanges) { // Firefox
        window.getSelection().removeAllRanges()
      }
    } else if (document.selection) { // IE?
      document.selection.empty()
    }
  }

  saveCmt (cmt) {
    cmt.page = hashPages(this.state.curPage)
    Storage.saveComments(cmt)
    const Cmts = this.state.Comments
    Cmts.push(cmt)
    this.setState({
      Comments: Cmts
    })
    if (window.getSelection) {
      if (window.getSelection().empty) { // Chrome
        window.getSelection().empty()
      } else if (window.getSelection().removeAllRanges) { // Firefox
        window.getSelection().removeAllRanges()
      }
    } else if (document.selection) { // IE?
      document.selection.empty()
    }
  }

  deletarHgt (id) {
    const Hgts = this.state.Highlights
    const hgtId = Hgts.findIndex(x => x.hashid == id)
    Hgts.splice(hgtId, 1)
    this.setState({
      Highlights: Hgts
    })
    Storage.deleteHighlight(id)
  }

  deletarCmt (cmt, hgt) {
    const stateHgt = this.state.Highlights
    const stateCmt = this.state.Comments

    const hgtId = stateHgt.findIndex(x => x.hashid == hgt)
    stateHgt.splice(hgtId, 1)

    const cmtId = stateCmt.findIndex(x => x.hashid == cmt)
    stateCmt.splice(cmtId, 1)

    this.setState({
      Comments: stateCmt,
      Highlights: stateHgt
    })

    Storage.deleteComment(cmt, hgt)
  }

  editarCmt (cmt, comment) {
    const stateCmt = this.state.Comments
    const cmtId = stateCmt.findIndex(x => x.hashid == cmt)

    stateCmt[cmtId].comment = comment

    this.setState({
      Comments: stateCmt
    })

    Storage.updateComment(cmt, comment)
  }

  async registraListeners () {
    $('.highlight, .highlight_cmt').off('click touchstart')
    $('.highlight, .highlight_cmt').click(async e => {
      e.stopImmediatePropagation()
      let hgt = null
      if ($(e.target).hasClass('normalDiv')) {
        let cur = $(e.target)
        do {
          cur = cur.parent()
        } while (!cur.hasClass('highlight') && !cur.hasClass('highlight_cmt') && !cur.hasClass('Ebook'))
        hgt = cur.attr('hgt')
        console.log('TargetCur:', cur)
      } else {
        hgt = $(e.target).attr('hgt')
      }

      console.log('Target:', $(e.target))
      console.log('HGT: ', hgt)
      if ($(e.target).hasClass('highlight_cmt')) {
        console.log(this.state)
        const cmt = this.state.Comments.find(x => x.highlight == hgt)

        const response = await CommentsFunctionalities.abrirMenuComentarios(cmt, hgt, this.state.Comments, hashPages(this.state.curPage))
        switch (response.type) {
          case 0:
            break
          // editar
          case 1:
            this.editarCmt(cmt.hashid, response.content)
            break
          // deletar
          case 2:
            this.deletarCmt(cmt.hashid, hgt)
            break
          default:
            break
        }
      } else {
        const response = await MarkerFunctionalities.deletarMarcacao(hgt, this.state.curPage)
        if (response) this.deletarHgt(hgt)
      }
    })
  }

  changePage () {
    CommentsFunctionalities.closeMenu_Comentarios()
    $('.delcmt').remove()
    if (!firstLoad) {
      console.log(this.state.Highlights)
      MarkerFunctionalities.rebuildHgt(this.state.Highlights, hashPages(this.state.curPage))
      this.registraListeners()
    }
  }

  render () {
    return (
      <StyledDiv>
        <IconButton edge='start' className='menuButton comments_btn' color='inherit' aria-label='menu'>
          <CommentsIcon />
        </IconButton>
        <IconButton edge='start' className='menuButton marker_btn' color='inherit' aria-label='menu'>
          <MarkerIcon />
        </IconButton>
      </StyledDiv>

    )
  }
}
export default Marker
