import React from 'react'

import List from '@material-ui/core/List'
import ListItem from '@material-ui/core/ListItem'
import ListItemIcon from '@material-ui/core/ListItemIcon'
import ListItemText from '@material-ui/core/ListItemText'
import Divider from '@material-ui/core/Divider'

import styled from 'styled-components'
import config from '../../local/js/config'
import sumario from '../../local/js/sumario_list'
import $ from 'jquery'

const StyledDiv = styled.div`
  .divider{
    position: absolute;
    top: 6vh;
    width: 100%;
  }

  margin-left: 0%;
  @media (min-width: ${config.MobileBreakpoint + 'px'}) {
    margin-left: 1%;
  }
  .MuiIconButton-root{
    cursor: pointer;
    background-color: transparent;
    padding: calc(1.3vh + 0vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      background-color: ${config.ButtonColor};
      padding: calc(0.2vh + 0.2vw);
    } 
  }
  .MuiIconButton-root:hover {
    background-color: ${config.ButtonColor};
  }
  .MuiSvgIcon-root{
    color: ${config.EbookColor};
    font-size: calc(2vh + 2vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      font-size: calc(1vh + 1vw);
    }
  }

  .menuButton{
    margin-left: 0%;
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      margin-left: 5%;
    }
  }
  .prevButton, .nextButton{
    background-color: ${config.ButtonColor} !important;
    padding: calc(0.8vh + 0vw) !important
  }
  .MuiLinearProgress-bar{
    background-color: ${config.EbookColor}
  }
  .itemText{
    font-size: ${props => props.sizeText + 'px'};
  }

  .MuiListItemIcon-root{
    min-width: 0;
    margin-right: 2vh;
  }
  
  
  
  display:none;
  flex: 1;
  height: auto;
  overflow: auto;
  
`
const Circle = styled.div`
  width: 5vh;
  height: 5vh;
  @media (min-width: ${config.MobileBreakpoint + 'px'}) {
    width: 4.5vh;
    height: 4.5vh
  }
  border-radius: 50%;
  border: solid;
  border-width: 0.3vh;
  border-color: lightgray;
  text-align: center;
  cursor: pointer;
  color: #cbc9c9;
  line-height: normal;
`
const LineIndicator = styled.div`
  position: absolute;
  top: 0;
  left: 0;
  width: 0.8vh;
  background-color: ${config.EbookColor};
  border-radius: 0.8vh;
  height: 6vh;
  transition: all linear 0.2s; 
`
const LineContainer = styled.div`
  position: absolute;
  top: 0;
  left: 0;
  width: 0.8vh;
  border-radius: 0.8vh;
  background-color: #e7e7e7;
  height: calc(100% - 16px);
  margin-top: 8px;
`

const fontratio = () => { return $(window).width() >= config.MobileBreakpoint ? 1 : 1 }

// Page
class Sumario extends React.Component {
  constructor (props) {
    super(props)
    $(document).on('open_sumario', () => {
      $('.lineIndicator').css('height', () => {
        let ht = 0
        for (const obj of sumario) {
          ht += $('#pg' + obj.paginaB).height()
          $('#circ' + obj.paginaB).css({ color: config.EbookColor, 'border-color': config.EbookColor })
          if (obj.paginaB == this.props.page) break
        }
        return ht + 'px'
      })
    })

    $(document).on('updateMaxPage', (e, page) => {
      $('.lineIndicator').css('height', () => {
        let ht = 0
        for (const obj of sumario) {
          if (obj.paginaB > page) break
          ht += $('#pg' + obj.paginaB).height()
          $('#circ' + obj.paginaB).css({ color: config.EbookColor, 'border-color': config.EbookColor })
        }
        return ht + 'px'
      })
    })
  }

  render () {
    return (
      <StyledDiv className='menu_sumario' sizeText={((fontratio() / 100) * ((95 / 100) * $(window).height())) + ((fontratio() / 100) * $(window).height())}>
        <Divider className='divider' />

        <List>
          {sumario.map((value, index) => {
            return <div id={'pg' + value.paginaB}>
              <ListItem button key={value.titulo} onClick={() => $(document).trigger('changePage', [value.paginaB, true, 'sumario', this.props.Code])} className='sumaryitem' style={{ 'min-height': '6vh' }}>
                <ListItemIcon>
                  <Circle id={'circ' + value.paginaB} className='circle align-items-center justify-content-center d-flex itemText' >{value.paginaB}</Circle>
                </ListItemIcon>
                <ListItemText primary={value.titulo} classes={{ primary: 'itemText' }} />
              </ListItem>

            </div>
          })}
          <LineContainer><LineIndicator className='lineIndicator' /></LineContainer>
        </List>

      </StyledDiv>
    )
  }
}
export default Sumario
