import React from 'react'
import styled from 'styled-components'
import NextIcon from '@material-ui/icons/NavigateNext'
import PrevIcon from '@material-ui/icons/NavigateBefore'
import IconButton from '@material-ui/core/IconButton'
import Box from '@material-ui/core/Box'
import $ from 'jquery'
import config from '../local/js/config'

const NavDiv = styled.div`
  width: 40%;
  height: 100%;
  position: relative;
  display: flex;
  float: left;
  @media (min-width: 750px) {
      width: 30%;
  }
  @media (min-width: 1000px) {
      width: 25%;
  } 
  @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      width: 25%;
  } 
  .pageCounter{
    flex: 1;
    color: ${config.FrameColor};
    background-color: white;
    border-radius: 2%;
    height: 60%;
    margin-left: 10px;
    margin-right: 20px;
    text-align: center;
    font-size: calc(1vw + 1vh) !important;
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      font-size: calc(0.5vw + 1vh) !important;
    } 
  }
  .MuiIconButton-root{
    cursor: pointer;
    background-color: white;
    border: 0.3vh solid white;
    padding: calc(1.3vh + 0vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      background-color: white;
      padding: calc(0.2vh + 0.2vw);
    }
    &:hover{
      background-color: white;
    }
  }
  .MuiIconButton-root:hover {
    background-color: white;
  }
  .MuiSvgIcon-root{
    color: ${config.EbookColor};
    font-size: calc(2vh + 2vw);
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      font-size: calc(2vh + 0.5vw);
    }
  }
  .menuButton{
    margin-left: 0%;
    @media (min-width: ${config.MobileBreakpoint + 'px'}) {
      margin-left: 5%;
    }
  }
  .prevButton, .nextButton{
    background-color: ${config.ButtonColor} !important;
    padding: calc(0.3vh + 0vw) !important
  }
  .MuiLinearProgress-bar{
    background-color: ${config.PrimaryColor}
  }

  .disabled {
    opacity: 0.5;
    cursor: default !important;
  }
`

// Component
class Nav extends React.Component {
  // Constructor
  constructor (props) {
    super(props)
    this.state = {
      curPage: this.props.curPage,
      maxPage: this.props.maxPage
    }

    $(document).on('updatePage', (e, page) => {
      this.setState({ curPage: page })
      $(document).ready(() => { this.buttonDisable() })
    })
  }

  buttonDisable () {
    if (this.state.curPage === 1) $('.prevButton').addClass('disabled')
    else $('.prevButton').removeClass('disabled')

    if (this.state.curPage === this.state.maxPage) $('.nextButton').addClass('disabled')
    else $('.nextButton').removeClass('disabled')
  }

  // Scripts

  // Called when rendered
  componentDidMount () {
    $('.prevButton').click((e) => {
      e.stopImmediatePropagation()
      $(document).trigger('changePage', [this.state.curPage - 1])
    })
    $('.nextButton').click((e) => {
      e.stopImmediatePropagation()
      $(document).trigger('changePage', [this.state.curPage + 1])
    })
    this.buttonDisable()
  }

  render () {
    return (
    // Content
      <NavDiv className='main d-flex align-items-center justify-content-between noselect'>
        <IconButton edge='start' className='prevButton' color='inherit' aria-label='menu'>
          <PrevIcon />
        </IconButton>
        <Box className='pageCounter d-flex align-items-center justify-content-center' boxShadow={1}>
          {this.state.curPage} / {this.state.maxPage}
        </Box>
        <IconButton edge='start' className='nextButton' color='inherit' aria-label='menu'>
          <NextIcon />
        </IconButton>
      </NavDiv>
    )
  }
}
export default Nav
